# If you change the compiler, you would need to change the BuildRequires
# to match
%define compiler gcc
%define mpidir %{_libdir}/%{name}/%{version}-%{compiler}

Summary: OSU MVAPICH2 MPI package
License: BSD
Group: Development/Libraries
Name: mvapich2
Version: 1.4
Release: 2%{?dist}
Source: mvapich2-%{version}.tgz
URL: http://mvapich.cse.ohio-state.edu/
Buildroot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: gcc-gfortran
BuildRequires: libibumad-devel, libibverbs-devel >= 1.1.2-4.el5, librdmacm-devel
Requires: mpi-selector, librdmacm-devel, libibverbs-devel, libibumad-devel
Requires(post): mpi-selector, rpm
Requires(preun): mpi-selector, rpm
ExclusiveArch: i386 ia64 x86_64

%description
This is an MPI-2 implementation which includes all MPI-1 features.  It is
based on MPICH2 and MVICH.

%prep
%setup -q -n %{name}-%{version}
export CC=gcc
export CXX=g++
export F77=gfortran
export F90=gfortran
export CFLAGS="-O3 -fno-strict-aliasing"
export CXXFLAGS="-O3"
export FFLAGS=""
export F90FLAGS=""
%ifarch i386
export CFLAGS="-m32 $CFLAGS"
export CXXFLAGS="-m32 $CXXFLAGS"
export FFLAGS="-m32 $FFLAGS"
export F90FLAGS="-m32 $F90FLAGS"
%endif
%ifarch x86_64
export CFLAGS="-m64 $CFLAGS"
export CXXFLAGS="-m64 $CXXFLAGS"
export FFLAGS="-m64 $FFLAGS"
export F90FLAGS="-m64 $F90FLAGS"
%endif
./configure --prefix=%{mpidir} --mandir=%{mpidir}/man --enable-error-checking=runtime --enable-timing=none --enable-g=mem,dbg,meminit --enable-mpe --enable-sharedlibs=gcc --with-rdma=gen2

%build
# The mvapich2 build script is not smp safe
make

%install
rm -fr %{buildroot}
make DESTDIR=%{buildroot} install
cd %{buildroot}%{mpidir}
rm -f sbin/mpeuninstall

# create the mpivars.[c]sh files.
cat >bin/mpivars.csh <<EOF
#!/bin/csh
if (\$?path) then
    if ( "\${path}" !~ *%{mpidir}/bin* ) then
	set path = ( %{mpidir}/bin \$path )
    endif
else
    set path = ( %{mpidir}/bin )
endif

if (\$?LD_CONFIG_PATH) then
    if ( "\${LD_CONFIG_PATH}" !~ *%{mpidir}/lib* ) then
	setenv LD_CONFIG_PATH %{mpidir}/lib:\$LD_CONFIG_PATH
    endif
else
    setenv LD_CONFIG_PATH %{mpidir}/lib:
endif

setenv MPD_BIN %{mpidir}/bin
EOF

cat >bin/mpivars.sh <<EOF
#!/bin/bash
if ! echo \${PATH} | grep -q %{mpidir}/bin ; then
    PATH=%{mpidir}/bin:\${PATH}
fi

if ! echo \${LD_LIBRARY_PATH} | grep -q %{mpidir}/lib ; then
    LD_CONFIG_PATH=%{mpidir}/lib:\${LD_CONFIG_PATH}
fi

export MPD_BIN=%{mpidir}/bin
EOF

%clean
rm -rf %{buildroot}

%post
# It is safe to reregister the same setup at every upgrade/reinstall/etc.
mpi-selector --register %{name}-%{version}-%{compiler}-%{_arch} \
    --source-dir %{mpidir}/bin --yes >/dev/null 2>&1
# We can't fail
/bin/true

%preun
# Count how many copies of this particular package are currently installed,
# knowing that on upgrade the new package being installed is already in this
# list by the time we are run, and that we are in the list too as we aren't
# removed until after our scripts complete.  If our count comes back as just
# 1, then we are the last copy of this particular version and we need to
# remove our registration.  This is true regardless of wheter this is an
# upgrade or an erase.  Note: we have to keep our arch in the query too or
# else multilib installations throw this count off.
COUNT=`rpm -q %{name}-%{version}.%{_arch} | wc -l`
if [ $COUNT -eq 1 ]; then
    mpi-selector --unregister %{name}-%{version}-%{compiler}-%{_arch} \
            --yes >/dev/null 2>&1
fi
/bin/true

%files
%defattr(-,root,root,-)
%dir %{mpidir}
%{mpidir}/*

%changelog
* Mon Aug 13 2012 Doug Ledford <dledford@redhat.com> - 1.4-2.el5
- Bump and rebuild against latest libibvbers, librdmacm, etc.
- Related: bz771441

* Tue Dec 22 2009 Doug Ledford <dledford@redhat.com> - 1.4-1.el5
- Update to latest upstream version
- Related: bz518218

* Mon Jun 22 2009 Doug Ledford <dledford@redhat.com> - 1.2-0.p1.3.el5
- Rebuild against libibverbs that isn't missing the proper ppc wmb() macro
- Related: bz506258

* Sun Jun 21 2009 Doug Ledford <dledford@redhat.com> - 1.2-0.p1.2.el5
- Compile against non-XRC libibverbs
- Related: bz506258

* Wed Apr 22 2009 Doug Ledford <dledford@redhat.com> - 1.2-0.p1.1
- Update to ofed 1.4.1-rc3 version
- Related: bz459652

* Thu Oct 16 2008 Doug Ledford <dledford@redhat.com> - 1.0.3-3
- Make sure MPD_BIN is set in the mpivars files
- Related: bz466390

* Fri Oct 03 2008 Doug Ledford <dledford@redhat.com> - 1.0.3-2
- Make scriptlets match mvapich
- Include a Requires(post) and Requires(preun) so installs work properly
- Resolves: bz465448

* Thu Sep 18 2008 Doug Ledford <dledford@redhat.com> - 1.0.3-1
- Initial rhel5 package
- Resolves: bz451477

* Sun May 04 2008 Jonathan Perkins <perkinjo@cse.ohio-state.edu>
- Created initial MVAPICH2 1.0.3 SRPM with IB and iWARP support.

